@@ -77,9 +77,9 @@ class ControlFile(object):
                    for k,v in self.options.iteritems()]
 	
         if self.bugtracker:
-            content.append("XSBC-Bugtracker: %s" % self.bugtracker)
+            content.append("Bugtracker: %s" % self.bugtracker)
         if self.displayname:
-            content.append("XB-Maemo-Display-Name: %s" % self.displayname)
+            content.append("Maemo-Display-Name: %s" % self.displayname)
 
         if self.description:
             self.description=self.description.replace("\n","\n ")
